summaryrefslogtreecommitdiff
path: root/modules/ldap
diff options
context:
space:
mode:
authorStefan Fritsch <sf@apache.org>2011-07-23 17:21:02 +0000
committerStefan Fritsch <sf@apache.org>2011-07-23 17:21:02 +0000
commit9674eb32cb74108cceab8ce457b6910fcfe9a479 (patch)
tree348b28d961064bf99a9db7c7d0b4ef2c3af27001 /modules/ldap
parent6e1307b58e3520fdbc7b16d1c9fd019a6365668f (diff)
downloadhttpd-9674eb32cb74108cceab8ce457b6910fcfe9a479.tar.gz
Revert r1129886:
Shift declaration logic of LDAP_DECLARE to ap_ldap.h from util_ldap.h git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/branches/revert-ap-ldap@1150169 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'modules/ldap')
-rw-r--r--modules/ldap/ap_ldap_init.c8
-rw-r--r--modules/ldap/ap_ldap_option.c8
-rw-r--r--modules/ldap/ap_ldap_rebind.c6
-rw-r--r--modules/ldap/ap_ldap_url.c10
4 files changed, 16 insertions, 16 deletions
diff --git a/modules/ldap/ap_ldap_init.c b/modules/ldap/ap_ldap_init.c
index 4802290251..ec34904e46 100644
--- a/modules/ldap/ap_ldap_init.c
+++ b/modules/ldap/ap_ldap_init.c
@@ -51,7 +51,7 @@
* will return APR_EGENERAL. Further LDAP specific error information
* can be found in result_err.
*/
-LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
const char *cert_auth_file,
int cert_file_type,
ap_ldap_err_t **result_err)
@@ -108,7 +108,7 @@ LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
* @todo currently we do not check whether ap_ldap_ssl_init()
* has been called first - should we?
*/
-LDAP_DECLARE(int) ap_ldap_ssl_deinit(void)
+MODLDAP_DECLARE(int) ap_ldap_ssl_deinit(void)
{
#if AP_HAS_LDAP_SSL && AP_HAS_LDAPSSL_CLIENT_DEINIT
@@ -139,7 +139,7 @@ LDAP_DECLARE(int) ap_ldap_ssl_deinit(void)
* AP_LDAP_SSL: SSL encryption (ldaps://)
* AP_LDAP_STARTTLS: Force STARTTLS on ldap://
*/
-LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
LDAP **ldap,
const char *hostname,
int portno,
@@ -179,7 +179,7 @@ LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
* This function returns a string describing the LDAP toolkit
* currently in use. The string is placed inside result_err->reason.
*/
-LDAP_DECLARE(int) ap_ldap_info(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_info(apr_pool_t *pool,
ap_ldap_err_t **result_err)
{
ap_ldap_err_t *result = (ap_ldap_err_t *)apr_pcalloc(pool, sizeof(ap_ldap_err_t));
diff --git a/modules/ldap/ap_ldap_rebind.c b/modules/ldap/ap_ldap_rebind.c
index 230986ef6b..0b93abc9d9 100644
--- a/modules/ldap/ap_ldap_rebind.c
+++ b/modules/ldap/ap_ldap_rebind.c
@@ -67,7 +67,7 @@ static apr_status_t ap_ldap_pool_cleanup_set_null(void *data_)
/* AP utility routine used to create the xref_lock. */
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool)
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool)
{
apr_status_t retcode = APR_SUCCESS;
@@ -89,7 +89,7 @@ LDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool)
}
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
LDAP *ld,
const char *bindDN,
const char *bindPW)
@@ -147,7 +147,7 @@ LDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
}
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_remove(LDAP *ld)
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_remove(LDAP *ld)
{
ap_ldap_rebind_entry_t *tmp_xref, *prev = NULL;
apr_status_t retcode = 0;
diff --git a/modules/ldap/ap_ldap_url.c b/modules/ldap/ap_ldap_url.c
index 8317990c75..f1fe2166ee 100644
--- a/modules/ldap/ap_ldap_url.c
+++ b/modules/ldap/ap_ldap_url.c
@@ -115,7 +115,7 @@ static char **ap_ldap_str2charray(apr_pool_t *pool,
* Is this URL an ldap url?
*
*/
-LDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url)
+MODLDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url)
{
int enclosed;
const char * scheme;
@@ -135,7 +135,7 @@ LDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url)
* Is this URL a secure ldap url?
*
*/
-LDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url)
+MODLDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url)
{
int enclosed;
const char * scheme;
@@ -155,7 +155,7 @@ LDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url)
* Is this URL an ldap socket url?
*
*/
-LDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url)
+MODLDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url)
{
int enclosed;
const char * scheme;
@@ -257,7 +257,7 @@ static int str2scope(const char *p)
* The LDAP result code and reason string is returned in the
* ap_ldap_err_t structure.
*/
-LDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
const char *url_in,
ap_ldap_url_desc_t **ludpp,
ap_ldap_err_t **result_err)
@@ -580,7 +580,7 @@ LDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
* The LDAP result code and reason string is returned in the
* ap_ldap_err_t structure.
*/
-LDAP_DECLARE(int) ap_ldap_url_parse(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_url_parse(apr_pool_t *pool,
const char *url_in,
ap_ldap_url_desc_t **ludpp,
ap_ldap_err_t **result_err)
diff --git a/modules/ldap/ap_ldap_option.c b/modules/ldap/ap_ldap_option.c
index d38ad21b07..84e770dc4b 100644
--- a/modules/ldap/ap_ldap_option.c
+++ b/modules/ldap/ap_ldap_option.c
@@ -38,12 +38,12 @@ static void option_set_tls(apr_pool_t *pool, LDAP *ldap, const void *invalue,
ap_ldap_err_t *result);
/**
* LDAP get option function
*
* This function gets option values from a given LDAP session if
* one was specified.
*/
-LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
LDAP *ldap,
int option,
void *outvalue,
@@ -72,7 +72,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
}
/**
* LDAP set option function
*
* This function sets option values to a given LDAP session if
* one was specified.
@@ -81,7 +81,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
* will try and apply legacy functions to achieve the same effect,
* depending on the platform.
*/
-LDAP_DECLARE(int) ap_ldap_set_option(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_set_option(apr_pool_t *pool,
LDAP *ldap,
int option,
const void *invalue,
@@ -38,12 +38,12 @@ static void option_set_tls(apr_pool_t *pool, LDAP *ldap, const void *invalue,
ap_ldap_err_t *result);
/**
- * LDAP get option function
+ * MODLDAP get option function
*
* This function gets option values from a given LDAP session if
@@ -72,7 +72,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
}
/**
- * LDAP set option function
+ * MODLDAP set option function
*
* This function sets option values to a given LDAP session if